var classplplot_1_1core_1_1plplotjavacJNI =
[
    [ "BASE_CONT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aae72e041820aab3cb0c665bb50d9c031", null ],
    [ "delete_PLGraphicsIn", "classplplot_1_1core_1_1plplotjavacJNI.html#a1d7be0b0c2e45eb328af3a0724d8a2b8", null ],
    [ "DRAW_LINEX_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a4ae96306dae305abfe6b865484585b26", null ],
    [ "DRAW_LINEXY_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a2f52398f1317caa98e32eeb12d3b878c", null ],
    [ "DRAW_LINEY_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a55620e6b0397d1833e69d4fe877cef5c", null ],
    [ "DRAW_SIDES_get", "classplplot_1_1core_1_1plplotjavacJNI.html#ae29a29a6dc31c02746e380652a402275", null ],
    [ "FACETED_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a9fc4bccdd3df27af8568f098a4282351", null ],
    [ "GRID_CSA_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a075a349b95ac00cd02f9e4d3cbd4d76b", null ],
    [ "GRID_DTLI_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a3646d4566edf7e885a1b697284ba53e8", null ],
    [ "GRID_NNAIDW_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aaa257cd0910eb57607a236bdf3590516", null ],
    [ "GRID_NNI_get", "classplplot_1_1core_1_1plplotjavacJNI.html#ab613a7bca3b3db99d3b356dc0fc3a402", null ],
    [ "GRID_NNIDW_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a910e5c1df356ac42be6a9c455a20aab5", null ],
    [ "GRID_NNLI_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a7b043f71b7c0a8d5514304062d393f5e", null ],
    [ "jPLFLTArray_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aab70c48039262d5b5f05effaa5024994", null ],
    [ "jPLFLTbracket2_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a4f157be8ea97da0e4487aae04dd0cfb9", null ],
    [ "jPLFLTbracket_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a87f60ac379f8740729c7ca5e85d9e572", null ],
    [ "MAG_COLOR_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a024c44fac6192f9782c4c441858598e2", null ],
    [ "MESH_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a20ef36a5df925b54b77a44601414b12c", null ],
    [ "new_PLGraphicsIn", "classplplot_1_1core_1_1plplotjavacJNI.html#a50fc773df1831c6226bf55c26a3ee712", null ],
    [ "ONEW2B_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a48108b997959f8917ea9405eeba4a127", null ],
    [ "ONEW2D_get", "classplplot_1_1core_1_1plplotjavacJNI.html#ac60c7e39ad16613ba0a03163d40943c7", null ],
    [ "PL_BIN_CENTRED_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a95af61284135870d831efed4b3723bd1", null ],
    [ "PL_BIN_DEFAULT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a3bfb4bdb9948dbdb0576cea0db460a21", null ],
    [ "PL_BIN_NOEMPTY_get", "classplplot_1_1core_1_1plplotjavacJNI.html#acd6f1424cec75d6d64fc28a0da65e074", null ],
    [ "PL_BIN_NOEXPAND_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a8ca4b2df8fbf6e7f36b8ff1793c286b5", null ],
    [ "PL_COLORBAR_BACKGROUND_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a8d1a6ee2387207691ce5609205cc703e", null ],
    [ "PL_COLORBAR_BOUNDING_BOX_get", "classplplot_1_1core_1_1plplotjavacJNI.html#ac4000ec1f6cc6c24c845e0c4a5b73786", null ],
    [ "PL_COLORBAR_CAP_HIGH_get", "classplplot_1_1core_1_1plplotjavacJNI.html#afc4425dab06ec8bab99f73081bf45817", null ],
    [ "PL_COLORBAR_CAP_LOW_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a88bc95cab8349b4edcf1345efb0bdef0", null ],
    [ "PL_COLORBAR_CAP_NONE_get", "classplplot_1_1core_1_1plplotjavacJNI.html#ae5196e239aaf6a545a5f41339cb7374b", null ],
    [ "PL_COLORBAR_GRADIENT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a21ffef2c634136768f4789350f7e8bf7", null ],
    [ "PL_COLORBAR_IMAGE_get", "classplplot_1_1core_1_1plplotjavacJNI.html#abe54140b4c5e7a66ae64b0a25bbf3408", null ],
    [ "PL_COLORBAR_LABEL_BOTTOM_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a1b121fc548584dc7eca83c7333cb71ff", null ],
    [ "PL_COLORBAR_LABEL_LEFT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#ae4c1f813430bb76abb534430bce12c57", null ],
    [ "PL_COLORBAR_LABEL_RIGHT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a94c0c69b230d5479a42c5b25d54f3f98", null ],
    [ "PL_COLORBAR_LABEL_TOP_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a106ce648c031215bfa0b0a73cda127a9", null ],
    [ "PL_COLORBAR_ORIENT_BOTTOM_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a6c13f3190f3c543826c12e5a2de5feb1", null ],
    [ "PL_COLORBAR_ORIENT_LEFT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aa5b6eae762059c756f0ae8d5fcec5253", null ],
    [ "PL_COLORBAR_ORIENT_RIGHT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#ae9c3bcf2a815cfcbc09a36a5080465f9", null ],
    [ "PL_COLORBAR_ORIENT_TOP_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a20a100b1ba91e4c8a430d2084f8ffd8c", null ],
    [ "PL_COLORBAR_SHADE_get", "classplplot_1_1core_1_1plplotjavacJNI.html#ac5f4db79e29310ea9f27a4e24a09361d", null ],
    [ "PL_COLORBAR_SHADE_LABEL_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aa921e2f07b1241ae021428f5ea9cae5e", null ],
    [ "PL_DRAWMODE_DEFAULT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#abffc963a2e7340dfd20acf4e59d16f2c", null ],
    [ "PL_DRAWMODE_REPLACE_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a4306048b2d89462d86f3a413ca50a008", null ],
    [ "PL_DRAWMODE_UNKNOWN_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a09b53b065b31f545a050116de26e646b", null ],
    [ "PL_DRAWMODE_XOR_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a6b800ee75a3f3e469ad4b00c4b50bc86", null ],
    [ "PL_FCI_BOLD_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a12fb1498e5deafe1cb5be1bf4f7f59b9", null ],
    [ "PL_FCI_FAMILY_get", "classplplot_1_1core_1_1plplotjavacJNI.html#abd85b5816cc2ae502b92477c49708593", null ],
    [ "PL_FCI_HEXDIGIT_MASK_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a07091f8ef6a35d6488a125fa51ab5202", null ],
    [ "PL_FCI_HEXPOWER_IMPOSSIBLE_get", "classplplot_1_1core_1_1plplotjavacJNI.html#acc2ded77e18f9c722c1cf26c7b4f5e38", null ],
    [ "PL_FCI_HEXPOWER_MASK_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a3257367afb3d16dd80e7f4f7bb3b40c7", null ],
    [ "PL_FCI_IMPOSSIBLE_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a7051dceffbc8a2db8f8d8e412a1df6e6", null ],
    [ "PL_FCI_ITALIC_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a26c96ab9666ea5e359c01ef5a9195d50", null ],
    [ "PL_FCI_MARK_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a0c1e50aba3f5496d488df33bc9e16c91", null ],
    [ "PL_FCI_MEDIUM_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a92d7c7b8007326689467d2e5f8b80c96", null ],
    [ "PL_FCI_MONO_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a301ca5b6a7857806dc5c842809b61b4f", null ],
    [ "PL_FCI_OBLIQUE_get", "classplplot_1_1core_1_1plplotjavacJNI.html#afeea4e127c68133be67e6b52458c2a57", null ],
    [ "PL_FCI_SANS_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a157faa0bc663a1df6edb6f2703e97320", null ],
    [ "PL_FCI_SCRIPT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a5c4398f7f55b899b0d89be98be28adc1", null ],
    [ "PL_FCI_SERIF_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a627bb37c1b74e04c21cb2e891d9b6261", null ],
    [ "PL_FCI_STYLE_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a6469db852184db8eea8e7677f1cd0435", null ],
    [ "PL_FCI_SYMBOL_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a04268ab093d0b50049f420f6bfa526de", null ],
    [ "PL_FCI_UPRIGHT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a58f6953dc0bfe656ac97d7ef7711fa7e", null ],
    [ "PL_FCI_WEIGHT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#ac098ef2c4586d4e41df7206b63662b24", null ],
    [ "PL_HIST_DEFAULT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a6a5c0529c0d42866589fe8e5ba1b69c1", null ],
    [ "PL_HIST_IGNORE_OUTLIERS_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a776170ae909411f2bbd564c48e7d6aa5", null ],
    [ "PL_HIST_NOEMPTY_get", "classplplot_1_1core_1_1plplotjavacJNI.html#ad40f4079d0bcabb8f7715d49a135f242", null ],
    [ "PL_HIST_NOEXPAND_get", "classplplot_1_1core_1_1plplotjavacJNI.html#acdeebd8dab5d7a1a7688263c99e848d4", null ],
    [ "PL_HIST_NOSCALING_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a13fe5fa730c4359aa907ae1fd93514f1", null ],
    [ "PL_LEGEND_BACKGROUND_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a147931d0db57e453742f865b8b595f25", null ],
    [ "PL_LEGEND_BOUNDING_BOX_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a3b97ab784acba22e522396f3fbb9d948", null ],
    [ "PL_LEGEND_COLOR_BOX_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aaf7d344d1e54fe5ca7382ff3abc7d0f8", null ],
    [ "PL_LEGEND_LINE_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a38b580278757bfe94374aa9c0d8deef3", null ],
    [ "PL_LEGEND_NONE_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a576523ca062ece9f1a3ee1f2c80ca2db", null ],
    [ "PL_LEGEND_ROW_MAJOR_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a6c032ceb951b08b36d9432ac2c2607ec", null ],
    [ "PL_LEGEND_SYMBOL_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a7841a01b418000a9f5b1f4aea8949b34", null ],
    [ "PL_LEGEND_TEXT_LEFT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#adf0e0f1f11039dfa40c643a4d6af2b8d", null ],
    [ "PL_MAXKEY_get", "classplplot_1_1core_1_1plplotjavacJNI.html#adb9a1a039fcb4a43c946a2cf4eb98dd1", null ],
    [ "PL_MAXWINDOWS_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a0de595079bed7cbfef9d564443f5b554", null ],
    [ "PL_NOTSET_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aca3abe0ece974abfe00ff5584e377197", null ],
    [ "PL_OPT_ARG_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a4db76d5246526e659970a78014ddbae0", null ],
    [ "PL_OPT_BOOL_get", "classplplot_1_1core_1_1plplotjavacJNI.html#adc6ca9070e7dbe10c47f115a8b7c619b", null ],
    [ "PL_OPT_DISABLED_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a6bb643cf36118dd8c1eb5e33c16d0da4", null ],
    [ "PL_OPT_ENABLED_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aea169aea7c50be76c2b8562f241d7a12", null ],
    [ "PL_OPT_FLOAT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aabe68544f1b95489d9636f7864be208f", null ],
    [ "PL_OPT_FUNC_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a901e2f5f8c60d1c70ced8f7cba228b07", null ],
    [ "PL_OPT_INT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a414b84cd1ecba5ffa68f6fe559421394", null ],
    [ "PL_OPT_INVISIBLE_get", "classplplot_1_1core_1_1plplotjavacJNI.html#af32659bf5ed1e4c4e219d6162c76cfc1", null ],
    [ "PL_OPT_NODELETE_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aa85a7714c768804ede67f6510361410d", null ],
    [ "PL_OPT_STRING_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a6e8dfbe0810ba94eb000fb3fe6bb711d", null ],
    [ "PL_PARSE_FULL_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a852462014395f0f4fe172d721c7d8958", null ],
    [ "PL_PARSE_NODASH_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a5fdbc9921b780258184e1a87760e3a14", null ],
    [ "PL_PARSE_NODELETE_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a1cc1447dc7875826426e6ac1bf61e3ce", null ],
    [ "PL_PARSE_NOPROGRAM_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a5be285394bdd366f6c56c7a2f9dd1e28", null ],
    [ "PL_PARSE_OVERRIDE_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a3c9a7f6761da96d690189446b88b8dd2", null ],
    [ "PL_PARSE_PARTIAL_get", "classplplot_1_1core_1_1plplotjavacJNI.html#ac2a1ff224abdf26f5cd1baf2c93fb34e", null ],
    [ "PL_PARSE_QUIET_get", "classplplot_1_1core_1_1plplotjavacJNI.html#acd59061578b0c8bbffc8fa2c6e65cf55", null ],
    [ "PL_PARSE_SHOWALL_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a4b2b99b0e27a4643bcc4b5f0d78f0818", null ],
    [ "PL_PARSE_SKIP_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a803d94d6e0f8739c596f72da900638d7", null ],
    [ "PL_POSITION_BOTTOM_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a0020487d828d1042aded3422e1f6a867", null ],
    [ "PL_POSITION_INSIDE_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a5dee3d5a876346eaf75d140d1a77ed43", null ],
    [ "PL_POSITION_LEFT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aadb351047255f40f28ad7cbce2787945", null ],
    [ "PL_POSITION_OUTSIDE_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a3f92c8420cc37a2cf968141c5d72dede", null ],
    [ "PL_POSITION_RIGHT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#abf7798c0e1e12c4274addbc9c18427f8", null ],
    [ "PL_POSITION_SUBPAGE_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a6cd2f3ab3bb09f3d7e53b2688b0486dc", null ],
    [ "PL_POSITION_TOP_get", "classplplot_1_1core_1_1plplotjavacJNI.html#ae2a1d5991724ad54159d094fd1893eb8", null ],
    [ "PL_POSITION_VIEWPORT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#acfd0925db9451c557b572a68bfcfd3f9", null ],
    [ "pl_setcontlabelformat", "classplplot_1_1core_1_1plplotjavacJNI.html#a965b0731b3050676e55f638dae028d58", null ],
    [ "pl_setcontlabelparam", "classplplot_1_1core_1_1plplotjavacJNI.html#ab0abd0539d51d24d0abdbd4706ab814d", null ],
    [ "PL_X_AXIS_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a2ba03eb13f3464c46fb2b35732e07cc5", null ],
    [ "PL_Y_AXIS_get", "classplplot_1_1core_1_1plplotjavacJNI.html#ab578ebc9516d2b43bd539eca50013403", null ],
    [ "PL_Z_AXIS_get", "classplplot_1_1core_1_1plplotjavacJNI.html#add3f6f193c60365ccc905d012baae03a", null ],
    [ "pladv", "classplplot_1_1core_1_1plplotjavacJNI.html#adc032e20530ec543475750f79ae86d88", null ],
    [ "plarc", "classplplot_1_1core_1_1plplotjavacJNI.html#a46634825578e95f17ef40ca7fb8b91b2", null ],
    [ "plaxes", "classplplot_1_1core_1_1plplotjavacJNI.html#ac99e12fdc263636d3ab47e864656a672", null ],
    [ "plbin", "classplplot_1_1core_1_1plplotjavacJNI.html#a1087bf1b98937706cea4524fb27fa1e1", null ],
    [ "plbop", "classplplot_1_1core_1_1plplotjavacJNI.html#a4ed3212a30f7d33ba2c0971631c51b75", null ],
    [ "plbox", "classplplot_1_1core_1_1plplotjavacJNI.html#ab7cc5d592f80f9c4a1cd2c7ec9ad86ee", null ],
    [ "plbox3", "classplplot_1_1core_1_1plplotjavacJNI.html#aa185c549fb19a565e1c4434e44a19527", null ],
    [ "plbtime", "classplplot_1_1core_1_1plplotjavacJNI.html#ad10f895e9ca4e82f10da709b642469a4", null ],
    [ "plcalc_world", "classplplot_1_1core_1_1plplotjavacJNI.html#ab02c5b58cb327b0ef90459af3c1d804f", null ],
    [ "plclear", "classplplot_1_1core_1_1plplotjavacJNI.html#ac3cc4cc468758bc642b49e76bda82e9d", null ],
    [ "plClearOpts", "classplplot_1_1core_1_1plplotjavacJNI.html#a2a427b202b387ae5033ff3406f1bd43f", null ],
    [ "plcol0", "classplplot_1_1core_1_1plplotjavacJNI.html#aa50e27e55bd623e3bceaf941cf248cdf", null ],
    [ "plcol1", "classplplot_1_1core_1_1plplotjavacJNI.html#a527e8dcfdcde10a79068dd058b3c1b0c", null ],
    [ "plcolorbar", "classplplot_1_1core_1_1plplotjavacJNI.html#ac2958545304c2fa351f9ad864c41e64a", null ],
    [ "plconfigtime", "classplplot_1_1core_1_1plplotjavacJNI.html#a53cc8d35cb883673572e3384a1527e00", null ],
    [ "plcont", "classplplot_1_1core_1_1plplotjavacJNI.html#a37bc05ddcfaa657867fddfe391a1ca78", null ],
    [ "plcpstrm", "classplplot_1_1core_1_1plplotjavacJNI.html#aebb09eb87cdfbcb4d37f2d67d7793463", null ],
    [ "plctime", "classplplot_1_1core_1_1plplotjavacJNI.html#aea36d7140ff4549ab710771b786c081f", null ],
    [ "plend", "classplplot_1_1core_1_1plplotjavacJNI.html#a3a19cc6c60862acc0d143f302b9223ba", null ],
    [ "plend1", "classplplot_1_1core_1_1plplotjavacJNI.html#a1541c945dacffc02f99c4fb8d8f7e51d", null ],
    [ "plenv", "classplplot_1_1core_1_1plplotjavacJNI.html#ad3269d6eb59e508777607644f2b2e755", null ],
    [ "plenv0", "classplplot_1_1core_1_1plplotjavacJNI.html#a773797987733a72529ebdb7bd6bb051c", null ],
    [ "pleop", "classplplot_1_1core_1_1plplotjavacJNI.html#a5d8fcb093de2fccac7d713a26986a175", null ],
    [ "plerrx", "classplplot_1_1core_1_1plplotjavacJNI.html#ac3a4980f635edf3f944482182d8b1a3f", null ],
    [ "plerry", "classplplot_1_1core_1_1plplotjavacJNI.html#abac95a0af408299a3a95279266748610", null ],
    [ "PLESC_ALLOC_NCOL_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aea9edda1459fc3b18580eb7dbd1d90b7", null ],
    [ "PLESC_APPEND_BUFFER_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a14381d0419a637627eb8074999705b6c", null ],
    [ "PLESC_ARC_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aa36fe8ff9f5a8858461c76a210c8d2a3", null ],
    [ "PLESC_BEGIN_TEXT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a0d17f2a2737c3cd9ad5543567e5b1b0a", null ],
    [ "PLESC_CLEAR_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a0a1d8b30487470d1bd73175c7e23d745", null ],
    [ "PLESC_CONTROL_CHAR_get", "classplplot_1_1core_1_1plplotjavacJNI.html#ac7bb13e3fa90ead81eb6b828094dcefc", null ],
    [ "PLESC_DASH_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a82afa327a320595d28cec247cc8a4a79", null ],
    [ "PLESC_DEV2PLCOL_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a86f97ed252e57b183bbb0c019bb8a2dc", null ],
    [ "PLESC_DEVINIT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a965ad3517a59664e7073273d6971be18", null ],
    [ "PLESC_DI_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a91bcd322b285a734037537d93374bd3c", null ],
    [ "PLESC_DOUBLEBUFFERING_DISABLE_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aadd9d77c527b8b02a1e42febeb2ff1fe", null ],
    [ "PLESC_DOUBLEBUFFERING_ENABLE_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a681c9220284274fe0edd2fc207fb6fc4", null ],
    [ "PLESC_DOUBLEBUFFERING_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a2d09875268da7e83e0e439c4edfc81de", null ],
    [ "PLESC_DOUBLEBUFFERING_QUERY_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aebf4c93b0c4a0abe0234673b91d9e095", null ],
    [ "PLESC_EH_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aa274a308f43b13eaddd5fd7ec67486b1", null ],
    [ "PLESC_END_RASTERIZE_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aeca054b2dacd7258cd50fe5b7c9822cd", null ],
    [ "PLESC_END_TEXT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a2bd2c9bb5ec143edfd7daec94e8554c2", null ],
    [ "PLESC_EXPOSE_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a066276ed94e38039312083208ba265e9", null ],
    [ "PLESC_FILL_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a0b39c36a8a969fa12467a41e952e7510", null ],
    [ "PLESC_FIXASPECT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#adc0374d67e34260fb6ce8def7c0ef181", null ],
    [ "PLESC_FLUSH_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aff852a6595dfe67e61e864430cf83cb6", null ],
    [ "PLESC_FLUSH_REMAINING_BUFFER_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aae9e3b0a42e98d6871a9da78e159d7f7", null ],
    [ "PLESC_GETBACKEND_get", "classplplot_1_1core_1_1plplotjavacJNI.html#abca643e49c0e7c5ebf91aabe490e4142", null ],
    [ "PLESC_GETC_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aa3b0aa3fd019c150dd61c921866003cd", null ],
    [ "PLESC_GRADIENT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a8900c4341b2490cab3aaeb440a93865d", null ],
    [ "PLESC_GRAPH_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a38be231526a09991ebc75a0cc5e718d6", null ],
    [ "PLESC_HAS_TEXT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aad01df012951b7efb2233edbd9f52d16", null ],
    [ "PLESC_IMAGE_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a2c074e1f1436d34676e95331e6282740", null ],
    [ "PLESC_IMAGEOPS_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aec0a63e4fd5a6bab2c36fb49af547286", null ],
    [ "PLESC_IMPORT_BUFFER_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a4fd56258635ed584c6950a3a1d702404", null ],
    [ "PLESC_MODEGET_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a9abc59d742b9c4b9cd382632dd9a361e", null ],
    [ "PLESC_MODESET_get", "classplplot_1_1core_1_1plplotjavacJNI.html#abcb01ce92c17e8d0e4c9deba5d80f1ee", null ],
    [ "PLESC_PL2DEVCOL_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a37f26a846af5f16f81430d6e65af1e8f", null ],
    [ "PLESC_REDRAW_get", "classplplot_1_1core_1_1plplotjavacJNI.html#afc197bd69053353f84e8e36eb5fca442", null ],
    [ "PLESC_RESIZE_get", "classplplot_1_1core_1_1plplotjavacJNI.html#af299b2aa83989d38953e3a5b457212ae", null ],
    [ "PLESC_SET_COMPRESSION_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a9a8a4be843f0fc20f068462759aa84c5", null ],
    [ "PLESC_SET_LPB_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a967ac86f3b6ee3f57e2ec9c043be45f2", null ],
    [ "PLESC_SET_RGB_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a761798937ed43f4335a8416654b8a705", null ],
    [ "PLESC_SETBGFG_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a6a2a0ab2281ed4e431a890edd6c392f3", null ],
    [ "PLESC_START_RASTERIZE_get", "classplplot_1_1core_1_1plplotjavacJNI.html#affe03bd6681b008d921d47ebd342aab6", null ],
    [ "PLESC_SWIN_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a49444fc4c8eb885437817a6dc4b837cc", null ],
    [ "PLESC_TEXT_CHAR_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aebb7804fc6ba6590de97f2313eca1864", null ],
    [ "PLESC_TEXT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#ae67c8f14c71d7da8255dc9b69d9967b3", null ],
    [ "PLESC_XORMOD_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aaec371cc676a698fa88996cadc2c20dc", null ],
    [ "plfamadv", "classplplot_1_1core_1_1plplotjavacJNI.html#af5bd2fb82bb30fc3cdcfa2581b980e7e", null ],
    [ "plfill", "classplplot_1_1core_1_1plplotjavacJNI.html#a983aa3d6ec4bee9fa1a21a7bca768b50", null ],
    [ "plfill3", "classplplot_1_1core_1_1plplotjavacJNI.html#a2512c0c571d8539f0a10589e685d9509", null ],
    [ "plflush", "classplplot_1_1core_1_1plplotjavacJNI.html#a4fa8103108f0da1fffb9c6b9605416d4", null ],
    [ "plfont", "classplplot_1_1core_1_1plplotjavacJNI.html#a8bb23ceb6e6c0dfce2145f49207d5fff", null ],
    [ "plfontld", "classplplot_1_1core_1_1plplotjavacJNI.html#a8d130d383fd74f8cea95f4bb8c10d5d1", null ],
    [ "plgchr", "classplplot_1_1core_1_1plplotjavacJNI.html#aab774e9e8bcc21f5aa1809318ff2a98e", null ],
    [ "plgcmap1_range", "classplplot_1_1core_1_1plplotjavacJNI.html#ac6a675f53b7460bc2cabe7e2b4afff82", null ],
    [ "plgcol0", "classplplot_1_1core_1_1plplotjavacJNI.html#a134a25b2899c2b7b77a8e268d7f88f98", null ],
    [ "plgcol0a", "classplplot_1_1core_1_1plplotjavacJNI.html#a18c6ba65cd172429cc184d2644db6940", null ],
    [ "plgcolbg", "classplplot_1_1core_1_1plplotjavacJNI.html#a27fe9b74ed1a29c49290dbe380b9a422", null ],
    [ "plgcolbga", "classplplot_1_1core_1_1plplotjavacJNI.html#a75b4faba96510ae6797fb608c09da82f", null ],
    [ "plgcompression", "classplplot_1_1core_1_1plplotjavacJNI.html#a3070ef8f6b352083c227c02cd13401c3", null ],
    [ "plgdev", "classplplot_1_1core_1_1plplotjavacJNI.html#a504457597e8d5e9c7e5a397e69f1a570", null ],
    [ "plgdidev", "classplplot_1_1core_1_1plplotjavacJNI.html#a16334ea8fabab11bc3dcf7228dbcbeca", null ],
    [ "plgdiori", "classplplot_1_1core_1_1plplotjavacJNI.html#ad93e69103dc6d967d06c68c5f1e91164", null ],
    [ "plgdiplt", "classplplot_1_1core_1_1plplotjavacJNI.html#aac8d9459e637d6ad2999135c1cd0e57a", null ],
    [ "plGetCursor", "classplplot_1_1core_1_1plplotjavacJNI.html#a16bba24741e6b94b184bf152d60d36e2", null ],
    [ "plgfam", "classplplot_1_1core_1_1plplotjavacJNI.html#abb4a230c2deef63a55dcead97fa2c971", null ],
    [ "plgfci", "classplplot_1_1core_1_1plplotjavacJNI.html#ab7161b7a2471985e66bf96d08159bf7d", null ],
    [ "plgfnam", "classplplot_1_1core_1_1plplotjavacJNI.html#a2087f4840c79972a53a47e816247136d", null ],
    [ "plgfont", "classplplot_1_1core_1_1plplotjavacJNI.html#a4ccef314797357773a8b85b7bc30a020", null ],
    [ "plglevel", "classplplot_1_1core_1_1plplotjavacJNI.html#ad072b7ca917020062aec91573fef50db", null ],
    [ "plgpage", "classplplot_1_1core_1_1plplotjavacJNI.html#aebe16b6a7fe0bf9d46d21aed374d4764", null ],
    [ "plgra", "classplplot_1_1core_1_1plplotjavacJNI.html#a3638fcda2a066eea305fc94f9396cbfc", null ],
    [ "plgradient", "classplplot_1_1core_1_1plplotjavacJNI.html#a7e5659ed3e3d2b5f2ff5c4cbc3626094", null ],
    [ "PLGraphicsIn_button_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a79ede5eefb495bf081c9ff41c975b57b", null ],
    [ "PLGraphicsIn_button_set", "classplplot_1_1core_1_1plplotjavacJNI.html#a3b0803f9ef20fbc9a9f6dd1918da4941", null ],
    [ "PLGraphicsIn_dX_get", "classplplot_1_1core_1_1plplotjavacJNI.html#ae0970b7ca5315625b955cfe2b8a059e6", null ],
    [ "PLGraphicsIn_dX_set", "classplplot_1_1core_1_1plplotjavacJNI.html#a0b508e88f8edf20490c4a610ec45f0c8", null ],
    [ "PLGraphicsIn_dY_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a81abc56da135de74bd0fdad9364eafd2", null ],
    [ "PLGraphicsIn_dY_set", "classplplot_1_1core_1_1plplotjavacJNI.html#a117c038b21a380daff09e1f794e896ec", null ],
    [ "PLGraphicsIn_keysym_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a174053989d2d3297d3db0096d865f032", null ],
    [ "PLGraphicsIn_keysym_set", "classplplot_1_1core_1_1plplotjavacJNI.html#ab8ca3b3643be8e128bce08c443ba5e19", null ],
    [ "PLGraphicsIn_pX_get", "classplplot_1_1core_1_1plplotjavacJNI.html#afa7bbc84ade0ea9a1db8dd57d226e61a", null ],
    [ "PLGraphicsIn_pX_set", "classplplot_1_1core_1_1plplotjavacJNI.html#ac1d8393de92a6d71729d01f24dad12fd", null ],
    [ "PLGraphicsIn_pY_get", "classplplot_1_1core_1_1plplotjavacJNI.html#ad895b7143baa2d5d29f4ffa2715e3bb6", null ],
    [ "PLGraphicsIn_pY_set", "classplplot_1_1core_1_1plplotjavacJNI.html#ad65f2f2deee446c893b94c3d0fa05397", null ],
    [ "PLGraphicsIn_state_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a030e6b5ad122a957279ee033d9c364c3", null ],
    [ "PLGraphicsIn_state_set", "classplplot_1_1core_1_1plplotjavacJNI.html#a4edce1a967a0cc4d9ba1aafd918f4cd5", null ],
    [ "PLGraphicsIn_string_get", "classplplot_1_1core_1_1plplotjavacJNI.html#ae646709ed18b911665ce05031411dccf", null ],
    [ "PLGraphicsIn_string_set", "classplplot_1_1core_1_1plplotjavacJNI.html#a815f27de3e02a752f6714428ce746f25", null ],
    [ "PLGraphicsIn_subwindow_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aeb0d0c72a0a5dcbfa5e518b6bfd3e04e", null ],
    [ "PLGraphicsIn_subwindow_set", "classplplot_1_1core_1_1plplotjavacJNI.html#a0a59e17cbe61f043991b123c8fe9d802", null ],
    [ "PLGraphicsIn_type_get", "classplplot_1_1core_1_1plplotjavacJNI.html#ab425b3ea436b08c5a5566da3f98961da", null ],
    [ "PLGraphicsIn_type_set", "classplplot_1_1core_1_1plplotjavacJNI.html#a9b7f6f9a58442578e3ca79c77b1e7520", null ],
    [ "PLGraphicsIn_wX_get", "classplplot_1_1core_1_1plplotjavacJNI.html#af5ba8da37031ae9539cab4c4d0607a5a", null ],
    [ "PLGraphicsIn_wX_set", "classplplot_1_1core_1_1plplotjavacJNI.html#ace03c5a3bcf0ad09d2032fd165d4d9e2", null ],
    [ "PLGraphicsIn_wY_get", "classplplot_1_1core_1_1plplotjavacJNI.html#ace2d9cc550d795b86dbded16cbc1f4f1", null ],
    [ "PLGraphicsIn_wY_set", "classplplot_1_1core_1_1plplotjavacJNI.html#a0d7e83707385e3ca3d6c957ee586e4af", null ],
    [ "plgriddata", "classplplot_1_1core_1_1plplotjavacJNI.html#a174b45fd5c192e9b4b0ee0467034dbbf", null ],
    [ "plgspa", "classplplot_1_1core_1_1plplotjavacJNI.html#adfa7e35c31ee046a09fdeaf27b732c55", null ],
    [ "plgstrm", "classplplot_1_1core_1_1plplotjavacJNI.html#a58d3fe94c62a26ccc4d0e0a644bd0a30", null ],
    [ "plgver", "classplplot_1_1core_1_1plplotjavacJNI.html#a0fcf4f0c82d01d265874831d68035837", null ],
    [ "plgvpd", "classplplot_1_1core_1_1plplotjavacJNI.html#ad1e5576eb011a3cf0f59ecb613d4dfb7", null ],
    [ "plgvpw", "classplplot_1_1core_1_1plplotjavacJNI.html#a55dfa6fecedb43c0adaeef0666397f0c", null ],
    [ "plgxax", "classplplot_1_1core_1_1plplotjavacJNI.html#a0e8ac944bd24e698f43555a916121734", null ],
    [ "plgyax", "classplplot_1_1core_1_1plplotjavacJNI.html#aad5b4e9c25dce3a6f3acb939fb9c5d8b", null ],
    [ "plgzax", "classplplot_1_1core_1_1plplotjavacJNI.html#a409a95f927fa243bb4de84908f2b5411", null ],
    [ "plhist", "classplplot_1_1core_1_1plplotjavacJNI.html#a6ef5875b5d4eaf62108f269ef949af25", null ],
    [ "plhlsrgb", "classplplot_1_1core_1_1plplotjavacJNI.html#a34d3cc72b4cc4225c7dfc0d08ca869de", null ],
    [ "plimage", "classplplot_1_1core_1_1plplotjavacJNI.html#a8bfeae11dc11b2409a90942faa2e3479", null ],
    [ "plimagefr", "classplplot_1_1core_1_1plplotjavacJNI.html#a3ae7a768e6314a06c1d54c7f5f345c53", null ],
    [ "plinit", "classplplot_1_1core_1_1plplotjavacJNI.html#a8eebbea099d84fec94dfbee15ba564af", null ],
    [ "pljoin", "classplplot_1_1core_1_1plplotjavacJNI.html#a9da3f011420bb42ac208ed4203234629", null ],
    [ "pllab", "classplplot_1_1core_1_1plplotjavacJNI.html#a0d1eeaf86419f1fbf29b8e3adc0ce8b1", null ],
    [ "pllegend", "classplplot_1_1core_1_1plplotjavacJNI.html#a655716bebba70dcb49cbd08aa3c44154", null ],
    [ "pllightsource", "classplplot_1_1core_1_1plplotjavacJNI.html#a2d593c080ad3545834fb63b6ca87a58b", null ],
    [ "plline", "classplplot_1_1core_1_1plplotjavacJNI.html#ae5b683191016ae650151840a3741f933", null ],
    [ "plline3", "classplplot_1_1core_1_1plplotjavacJNI.html#a4dbcc1f886f82f70cfb5216311d2d823", null ],
    [ "pllsty", "classplplot_1_1core_1_1plplotjavacJNI.html#a649aa5680159ea5e3abac44b1a61757e", null ],
    [ "plmap", "classplplot_1_1core_1_1plplotjavacJNI.html#abc69bb4b4bdde4a75222bde94ad667f7", null ],
    [ "plmapfill", "classplplot_1_1core_1_1plplotjavacJNI.html#ae65d5a5d3e5f356dc28cebdf2acc10b9", null ],
    [ "plmapline", "classplplot_1_1core_1_1plplotjavacJNI.html#aae104760a2036531776c64b6409ab6ff", null ],
    [ "plmapstring", "classplplot_1_1core_1_1plplotjavacJNI.html#ac4686b5179570ecf8f50d556bd9e38b6", null ],
    [ "plmaptex", "classplplot_1_1core_1_1plplotjavacJNI.html#af6022f29e0dfd0482d2ea9b92c1c482f", null ],
    [ "plmeridians", "classplplot_1_1core_1_1plplotjavacJNI.html#aeb62093153bf894d263a6aad628e5ba9", null ],
    [ "plmesh", "classplplot_1_1core_1_1plplotjavacJNI.html#abe05ea069c29a7d8ae005f6f7fc5ba32", null ],
    [ "plmeshc", "classplplot_1_1core_1_1plplotjavacJNI.html#a0e514d9afdebbe7fff032391f9f11fbf", null ],
    [ "plMinMax2dGrid", "classplplot_1_1core_1_1plplotjavacJNI.html#a93aa021054c164bc9de801072109ab0f", null ],
    [ "plmkstrm", "classplplot_1_1core_1_1plplotjavacJNI.html#ab994ad3f470b5f4a3f3fd60d69acab04", null ],
    [ "plmtex", "classplplot_1_1core_1_1plplotjavacJNI.html#aecfefa666af03faf7904ae9ec0a2df17", null ],
    [ "plmtex3", "classplplot_1_1core_1_1plplotjavacJNI.html#a0ed83e781b9a7ec37ff45a3269f36521", null ],
    [ "plOptUsage", "classplplot_1_1core_1_1plplotjavacJNI.html#a0dad9b5c87f0cae7b2e2a69f9a4f4809", null ],
    [ "plot3d", "classplplot_1_1core_1_1plplotjavacJNI.html#ab26e3257b37d22c616d74d808969eb22", null ],
    [ "plot3dc", "classplplot_1_1core_1_1plplotjavacJNI.html#a2e6ced55b8fe1a6eac0f65d927321545", null ],
    [ "plot3dcl", "classplplot_1_1core_1_1plplotjavacJNI.html#a5d88c1b4dfb378c277f16e383c11b1e8", null ],
    [ "plparseopts", "classplplot_1_1core_1_1plplotjavacJNI.html#a89d0b48b55a3f54b7eacbd0ce7ca9b45", null ],
    [ "plpat", "classplplot_1_1core_1_1plplotjavacJNI.html#a94bd4f991941afeaa85503b8fc91cbe4", null ],
    [ "plpath", "classplplot_1_1core_1_1plplotjavacJNI.html#a31cf154da0bbb45874c5dab741b263ad", null ],
    [ "plpoin", "classplplot_1_1core_1_1plplotjavacJNI.html#aa72160b8b2ce94a84be6757d4b227ae6", null ],
    [ "plpoin3", "classplplot_1_1core_1_1plplotjavacJNI.html#aca60bff2e3e201c92717d810405e167b", null ],
    [ "plpoly3", "classplplot_1_1core_1_1plplotjavacJNI.html#ad8c0c97246d6e79c547eb5c1b0bdeca2", null ],
    [ "plprec", "classplplot_1_1core_1_1plplotjavacJNI.html#a22cf990f455ffdd551496785a0cba9c3", null ],
    [ "plpsty", "classplplot_1_1core_1_1plplotjavacJNI.html#aff6e660337cda1a785543fa95f4cd0f8", null ],
    [ "plptex", "classplplot_1_1core_1_1plplotjavacJNI.html#ac1994129ac69451745e5fdd928a0bf0f", null ],
    [ "plptex3", "classplplot_1_1core_1_1plplotjavacJNI.html#a613c4812b5068a14e2584daff63664d1", null ],
    [ "plrandd", "classplplot_1_1core_1_1plplotjavacJNI.html#aa414e04c0e95dc361b7253b36773a74b", null ],
    [ "plreplot", "classplplot_1_1core_1_1plplotjavacJNI.html#afd3d88176b232293d2adae71ad2d436a", null ],
    [ "plResetOpts", "classplplot_1_1core_1_1plplotjavacJNI.html#a333d84de478149f60fc129dd1a6a1671", null ],
    [ "plrgbhls", "classplplot_1_1core_1_1plplotjavacJNI.html#a4b7819438b9bc2ffcfb2f7da66f1df9e", null ],
    [ "plschr", "classplplot_1_1core_1_1plplotjavacJNI.html#af3fba0702a980ade73ca201bbd02b98b", null ],
    [ "plscmap0", "classplplot_1_1core_1_1plplotjavacJNI.html#aa563b9523526efa780cf52529f17450d", null ],
    [ "plscmap0a", "classplplot_1_1core_1_1plplotjavacJNI.html#ad260bc411822a16b20bd77e4a030228f", null ],
    [ "plscmap0n", "classplplot_1_1core_1_1plplotjavacJNI.html#ae8c7a2c0bbde71b3a4e72d31d1af85df", null ],
    [ "plscmap1", "classplplot_1_1core_1_1plplotjavacJNI.html#ae3741475e54e0b0879a7ed32fdcc5c41", null ],
    [ "plscmap1_range", "classplplot_1_1core_1_1plplotjavacJNI.html#a12fa735818d64b1f8f4752b620bcfd92", null ],
    [ "plscmap1a", "classplplot_1_1core_1_1plplotjavacJNI.html#a88ea560f6b405fce3d524a8331af1d7a", null ],
    [ "plscmap1l", "classplplot_1_1core_1_1plplotjavacJNI.html#ac154519542912ae8faa241ef502d84eb", null ],
    [ "plscmap1la", "classplplot_1_1core_1_1plplotjavacJNI.html#a2fc3c9de0446f6bd2deaa33e008bb5eb", null ],
    [ "plscmap1n", "classplplot_1_1core_1_1plplotjavacJNI.html#a1d0fddcbb36e3f6e0f14c7f80d91c62d", null ],
    [ "plscol0", "classplplot_1_1core_1_1plplotjavacJNI.html#a371f7b13a460d4c3a6f9e2eaafdc4058", null ],
    [ "plscol0a", "classplplot_1_1core_1_1plplotjavacJNI.html#ae4d09bc9304e5cf311c03528ac92709d", null ],
    [ "plscolbg", "classplplot_1_1core_1_1plplotjavacJNI.html#ab368f604b72ab7657cf6c72dc851c910", null ],
    [ "plscolbga", "classplplot_1_1core_1_1plplotjavacJNI.html#ae98a160b30aef6a84d4472dcb9f8fea6", null ],
    [ "plscolor", "classplplot_1_1core_1_1plplotjavacJNI.html#a7b2fed9dd47e461bc9917b95969f3844", null ],
    [ "plscompression", "classplplot_1_1core_1_1plplotjavacJNI.html#a7cd3cd0093b55b3a4d06d251f1ab9309", null ],
    [ "plsdev", "classplplot_1_1core_1_1plplotjavacJNI.html#a4c0514efc4b1b8ff25c25ef9d8e824c9", null ],
    [ "plsdidev", "classplplot_1_1core_1_1plplotjavacJNI.html#a7a7c84d728a4698d5cb62fc43377aae1", null ],
    [ "plsdimap", "classplplot_1_1core_1_1plplotjavacJNI.html#a57de91268cdbb56a6a5eabdef339353f", null ],
    [ "plsdiori", "classplplot_1_1core_1_1plplotjavacJNI.html#aa14611b034fcab1255e3b2aba36d0eba", null ],
    [ "plsdiplt", "classplplot_1_1core_1_1plplotjavacJNI.html#abea9c414511541fb1ab1cf9e946e7490", null ],
    [ "plsdiplz", "classplplot_1_1core_1_1plplotjavacJNI.html#a17655a295ba3818e3420c4aafe57f661", null ],
    [ "plseed", "classplplot_1_1core_1_1plplotjavacJNI.html#a823de71be5d695a59d596066a38eefb6", null ],
    [ "plsesc", "classplplot_1_1core_1_1plplotjavacJNI.html#ab8369e556ea2b3b666e3a6bf73d84225", null ],
    [ "plsetopt", "classplplot_1_1core_1_1plplotjavacJNI.html#aa1d465f4d1c59a00495d8cb0d170527a", null ],
    [ "plSetUsage", "classplplot_1_1core_1_1plplotjavacJNI.html#a1e34d360cd060caa03ab47f0e71b753c", null ],
    [ "plsfam", "classplplot_1_1core_1_1plplotjavacJNI.html#a464dfce179c4fee995eb2c3c32ef5fc0", null ],
    [ "plsfci", "classplplot_1_1core_1_1plplotjavacJNI.html#a895c35bcf86cba946f6ed50c5b7026bb", null ],
    [ "plsfnam", "classplplot_1_1core_1_1plplotjavacJNI.html#a11bb0226ad8d03a473a44077e8b3ba57", null ],
    [ "plsfont", "classplplot_1_1core_1_1plplotjavacJNI.html#a70dbc1951b63941fc51452f91f6bb00e", null ],
    [ "plshade", "classplplot_1_1core_1_1plplotjavacJNI.html#a61a36ddf1de3f80367b657642fa849e8", null ],
    [ "plshades", "classplplot_1_1core_1_1plplotjavacJNI.html#afe873e9b7bdab4576253a936453e671a", null ],
    [ "plslabelfunc", "classplplot_1_1core_1_1plplotjavacJNI.html#a90b512db0a35b552d46d5cd7caf4462b", null ],
    [ "plsmaj", "classplplot_1_1core_1_1plplotjavacJNI.html#aa0e33e5e9a8feaaab4d7c8b4bb86dde0", null ],
    [ "plsmin", "classplplot_1_1core_1_1plplotjavacJNI.html#ac3843053adaacecce12a6e2aff655585", null ],
    [ "plsori", "classplplot_1_1core_1_1plplotjavacJNI.html#a2951eba3deed5a864bebee595fc3c25a", null ],
    [ "plspage", "classplplot_1_1core_1_1plplotjavacJNI.html#ac73595bf4e0fbcd31af4ef6ec4c611f7", null ],
    [ "plspal0", "classplplot_1_1core_1_1plplotjavacJNI.html#a0e5c684928330d0cbd023599b34e684e", null ],
    [ "plspal1", "classplplot_1_1core_1_1plplotjavacJNI.html#ac075cbc28f56d0affc04bbb8f6e815c0", null ],
    [ "plspause", "classplplot_1_1core_1_1plplotjavacJNI.html#ad1af10302878b80604335e3111b0842d", null ],
    [ "plsstrm", "classplplot_1_1core_1_1plplotjavacJNI.html#a4b6299de28fece02557295ab410c2596", null ],
    [ "plssub", "classplplot_1_1core_1_1plplotjavacJNI.html#a728326e101495c8f60704b8674290935", null ],
    [ "plssym", "classplplot_1_1core_1_1plplotjavacJNI.html#af21385e841bb26e498d439e491d0e609", null ],
    [ "plstar", "classplplot_1_1core_1_1plplotjavacJNI.html#acfe5cd08de6348ced4b961a8767afde7", null ],
    [ "plstart", "classplplot_1_1core_1_1plplotjavacJNI.html#afb59d717187483ce722e393f736fb529", null ],
    [ "plstransform", "classplplot_1_1core_1_1plplotjavacJNI.html#a80e325129f978466f75117db063f86ab", null ],
    [ "plstring", "classplplot_1_1core_1_1plplotjavacJNI.html#a9e82266dda7d4bd55414e7b3ebd78e3d", null ],
    [ "plstring3", "classplplot_1_1core_1_1plplotjavacJNI.html#a07f17e14b37009b326d99fe6d923ee68", null ],
    [ "plstripa", "classplplot_1_1core_1_1plplotjavacJNI.html#ad4ff2690fd5f05c5eb11bcafb99bb9fe", null ],
    [ "plstripc", "classplplot_1_1core_1_1plplotjavacJNI.html#a861b4a0fd8d566d2364b91849deca281", null ],
    [ "plstripd", "classplplot_1_1core_1_1plplotjavacJNI.html#a1708675594f51cf47bdbc97ab0ee66cb", null ],
    [ "plstyl", "classplplot_1_1core_1_1plplotjavacJNI.html#a71b2aba79b3e1097aa130a8b59c0110b", null ],
    [ "plsurf3d", "classplplot_1_1core_1_1plplotjavacJNI.html#ac4c633ae891c98f82d098c8a3a8c09b9", null ],
    [ "plsurf3dl", "classplplot_1_1core_1_1plplotjavacJNI.html#a6b94e4bd0d67d4334fcdf162866043a1", null ],
    [ "plsvect", "classplplot_1_1core_1_1plplotjavacJNI.html#a0d25ac546341d695a5dc1a4907c4cdee", null ],
    [ "plsvpa", "classplplot_1_1core_1_1plplotjavacJNI.html#a40203c80808c285c2903055771b85c65", null ],
    [ "PLSWIN_DEVICE_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a20053f6e86358666d4988dceda4581c9", null ],
    [ "PLSWIN_WORLD_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a770d39228e632253c56d70e92f404ccb", null ],
    [ "plsxax", "classplplot_1_1core_1_1plplotjavacJNI.html#a41fe006d7c023963abb074b0b293a151", null ],
    [ "plsyax", "classplplot_1_1core_1_1plplotjavacJNI.html#a9a236e3faa606786b10856015e8ddaf9", null ],
    [ "plsym", "classplplot_1_1core_1_1plplotjavacJNI.html#abec399b569312dcf7c3341b603a26f4f", null ],
    [ "plszax", "classplplot_1_1core_1_1plplotjavacJNI.html#a4740b61eb5e2ffce0828b5f26e732669", null ],
    [ "pltext", "classplplot_1_1core_1_1plplotjavacJNI.html#a7bd22cddb9a3640f3cd204a8567cfca0", null ],
    [ "PLTEXT_BACKCHAR_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a8c944f7826174336722ac7438a38819f", null ],
    [ "PLTEXT_FONTCHANGE_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a6c3bc04d8eb036621189c5614059441b", null ],
    [ "PLTEXT_OVERLINE_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aa2e677584d681f8855384b7b3c362ad7", null ],
    [ "PLTEXT_SUBSCRIPT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#af01fcf43349ca4fb6a83f0d626f28a67", null ],
    [ "PLTEXT_SUPERSCRIPT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a871ab748973127313fb9e3a0d2bb735b", null ],
    [ "PLTEXT_UNDERLINE_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a29dc9fcf0f80573dde3e8566ef687ed1", null ],
    [ "pltimefmt", "classplplot_1_1core_1_1plplotjavacJNI.html#a22a22d12dbb97ff655a8db7011ddc7c9", null ],
    [ "plvasp", "classplplot_1_1core_1_1plplotjavacJNI.html#ac70cb46258f5014534b3851efb2ba15a", null ],
    [ "plvect", "classplplot_1_1core_1_1plplotjavacJNI.html#a9b08fb48beced1a79d956d8a1186c8fe", null ],
    [ "plvpas", "classplplot_1_1core_1_1plplotjavacJNI.html#affc4a5f6cabf0af64994f1d615737fa2", null ],
    [ "plvpor", "classplplot_1_1core_1_1plplotjavacJNI.html#a97d910743b2b154e199480c077822f5a", null ],
    [ "plvsta", "classplplot_1_1core_1_1plplotjavacJNI.html#a522a271673e4bd05ac3632895e03fd65", null ],
    [ "plw3d", "classplplot_1_1core_1_1plplotjavacJNI.html#ac923fef3a89354581c8cf10e0b3b0894", null ],
    [ "plwidth", "classplplot_1_1core_1_1plplotjavacJNI.html#a32ac5d4111d4ba92b11ce1fd3f96084e", null ],
    [ "plwind", "classplplot_1_1core_1_1plplotjavacJNI.html#ae11ef2c78ca7f87b62228dcaa3f913c6", null ],
    [ "plxormod", "classplplot_1_1core_1_1plplotjavacJNI.html#a51d17bd4551d4809ce6027332a0b1576", null ],
    [ "SURF_CONT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a8aefa8e92cbfa3f414b2098fcf441ca6", null ],
    [ "TOP_CONT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a76b552e9f43e5ddce941de19102d17df", null ],
    [ "ZEROW2B_get", "classplplot_1_1core_1_1plplotjavacJNI.html#ab56ccb082d5c932a01997af206fd8e10", null ],
    [ "ZEROW2D_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aaee003ed49acbc14f6cad4854ebc1a9a", null ]
];